# coding:utf-8
import os

import matplotlib.pyplot as plt
from pymatgen.electronic_structure.plotter import BSPlotter

from dspawpy.io.read import get_band_data

datafile = "dspawpy_proj/dspawpy_tests/inputs/supplement/pband.h5"  # 指定数据文件路径
band_data = get_band_data(
    band_dir=datafile,
    syst_dir=None,  # system.json文件路径，仅当band_dir为json文件时需要
    efermi=None,  # 用于手动修正费米能级
    zero_to_efermi=True,  # 非金属体系应将零点能移动到费米能级
)

bsp = BSPlotter(band_data)
axes_or_plt = bsp.get_plot(
    zero_to_efermi=False,  # 上面读取数据时已经平移，此处应关闭
    ylim=[-10, 10],  # 能带图的纵坐标范围
    smooth=False,  # 是否对能带图进行平滑处理
    vbm_cbm_marker=False,  # 是否在能带图中标记导带和价带
    smooth_tol=0,  # 平滑处理的阈值
    smooth_k=3,  # 平滑处理的阶数
    smooth_np=100,  # 平滑处理的点数
)

if isinstance(axes_or_plt, plt.Axes):
    fig = axes_or_plt.get_figure()  # version newer than v2023.8.10
else:
    fig = axes_or_plt.gcf()  # older version pymatgen

# 添加能量零点参考线
for ax in fig.axes:
    ax.axhline(0, lw=2, ls="-.", color="gray")

figname = "dspawpy_proj/dspawpy_tests/outputs/us/4bandplot.png"  # 输出的能带图文件名
os.makedirs(os.path.dirname(os.path.abspath(figname)), exist_ok=True)
fig.savefig(figname, dpi=300)
